DummyVal

Struct DummyVal 

pub struct DummyVal { /* private fields */ }
Wrapper around u16.

Implementations

Source

impl DummyVal

pub fn new(val: u16, modulus: u16) -> Self

Create a new DummyVal.

pub fn new_bool(val: bool) -> Self

Create a new boolean DummyVal.

pub fn val(&self) -> u16

Extract the value.

pub fn rand_bool<RNG: CryptoRng + RngCore>(rng: &mut RNG) -> Self

Generate a random boolean DummyVal.

pub fn rand<RNG: CryptoRng + RngCore>(modulus: u16, rng: &mut RNG) -> Self

Generate a random DummyVal.

pub fn to_crt(value: u128, modulus: u128) -> CrtBundle<Self>

Generate a new CrtBundle of value % modulus.

pub fn from_crt(crt: &Bundle<Self>, modulus: u128) -> u128

Convert a Bundle representing a CRT value into its underlying u128.

pub fn to_binary(value: u128, nbits: usize) -> BinaryBundle<Self>

Generate a new BinaryBundle of value.

pub fn from_binary(bin: &Bundle<Self>) -> u128

Convert a Bundle representing a binary value into its underlying u128.

pub fn to_mixed_radix(value: u128, radii: &[u16]) -> CrtBundle<Self>

Generate a new mixed radix form Bundle for value using the provided radii.

pub fn from_mixed_radix(bundle: &CrtBundle<Self>) -> u128

Convert a Bundle representing mixed radix form into its underlying u128.