pub struct DummyVal { /* private fields */ }Expand description
Wrapper around u16.
Implementations
Sourceimpl DummyVal
impl DummyVal
Sourcepub fn rand_bool<RNG: CryptoRng + RngCore>(rng: &mut RNG) -> Self
pub fn rand_bool<RNG: CryptoRng + RngCore>(rng: &mut RNG) -> Self
Generate a random boolean DummyVal.
Sourcepub fn rand<RNG: CryptoRng + RngCore>(modulus: u16, rng: &mut RNG) -> Self
pub fn rand<RNG: CryptoRng + RngCore>(modulus: u16, rng: &mut RNG) -> Self
Generate a random DummyVal.
Sourcepub fn to_crt(value: u128, modulus: u128) -> CrtBundle<Self>
pub fn to_crt(value: u128, modulus: u128) -> CrtBundle<Self>
Generate a new CrtBundle of value % modulus.
Sourcepub fn from_crt(crt: &Bundle<Self>, modulus: u128) -> u128
pub fn from_crt(crt: &Bundle<Self>, modulus: u128) -> u128
Convert a Bundle representing a CRT value into its underlying
u128.
Sourcepub fn to_binary(value: u128, nbits: usize) -> BinaryBundle<Self>
pub fn to_binary(value: u128, nbits: usize) -> BinaryBundle<Self>
Generate a new BinaryBundle of value.
Sourcepub fn from_binary(bin: &Bundle<Self>) -> u128
pub fn from_binary(bin: &Bundle<Self>) -> u128
Convert a Bundle representing a binary value into its underlying
u128.
Sourcepub fn to_mixed_radix(value: u128, radii: &[u16]) -> CrtBundle<Self>
pub fn to_mixed_radix(value: u128, radii: &[u16]) -> CrtBundle<Self>
Generate a new mixed radix form Bundle for value using the
provided radii.
Sourcepub fn from_mixed_radix(bundle: &CrtBundle<Self>) -> u128
pub fn from_mixed_radix(bundle: &CrtBundle<Self>) -> u128
Convert a Bundle representing mixed radix form into its underlying
u128.